
import 'package:card_app/data/dtos/words_dto.dart';
import 'package:card_app/data/mappers/words_mapper.dart';
import 'package:card_app/repositories/api_interface.dart';
import 'package:dio/dio.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';

import '../domain/models/card.dart';

class WordsRepository extends ApiInterface{
  static final Dio _dio = Dio()
      ..interceptors.add(PrettyDioLogger(
        requestHeader: true,
        requestBody: true,
      ));

  static const String _baseUrl = 'https://api.potterdb.com';



  @override
  Future<List<CardData>?> loadData({String? q, int pageSize = 5}) async{
    try {
      const String url = '$_baseUrl/v1/characters';

      final Response<dynamic> response = await _dio.get<Map<dynamic, dynamic>>(
        url,
        queryParameters: {
          'filter[name_cont]': q,
          'page[size]': pageSize
        },
      );
      final WordsDto dto = WordsDto.fromJson(response.data as Map<String, dynamic>);
      final List<CardData>? data = dto.data?.map((e) => e.toDomain()).toList();
      return data;
    } on DioException catch (e) {
  return null;
  }
  }


}
